gs_quant.timeseries.analysis.last — gs_quant 0.1 documentation

# gs_quant.timeseries.analysis.last

`last`(x)

  Last value of series (as a series)

  Parameters

    x (`Series`) – time series

  Return type

    `Series`

  Returns

    time series of last value

  Usage

  Return series with last value of X for all dates:

  \(R_t = X_T\)

  where \(X_T\) is the last value in the series

  Examples

  Last value of series:

      >>> series = generate_series(100)
      >>> returns = last(series)

  See also

  `first()`